/****************************************************************************
** Meta object code from reading C++ file 'oggencwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../audex-26.04.3/widgets/oggencwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'oggencwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12oggencWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto oggencWidget::qt_create_metaobjectdata<qt_meta_tag_ZN12oggencWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "oggencWidget",
        "triggerChanged",
        "",
        "save",
        "quality_changed_by_slider",
        "quality",
        "quality_changed_by_spinbox",
        "set_bitrate",
        "enable_min_bitrate",
        "enable",
        "set_minbitrate",
        "bitrate",
        "enable_max_bitrate",
        "set_maxbitrate",
        "trigger_changed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'triggerChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<bool()>(3, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'quality_changed_by_slider'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'quality_changed_by_spinbox'
        QtMocHelpers::SlotData<void(double)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 5 },
        }}),
        // Slot 'set_bitrate'
        QtMocHelpers::SlotData<void(float)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Float, 5 },
        }}),
        // Slot 'enable_min_bitrate'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'set_minbitrate'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'enable_max_bitrate'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'set_maxbitrate'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'trigger_changed'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<oggencWidget, qt_meta_tag_ZN12oggencWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject oggencWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<oggencWidgetUI::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12oggencWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12oggencWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12oggencWidgetE_t>.metaTypes,
    nullptr
} };

void oggencWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<oggencWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->triggerChanged(); break;
        case 1: { bool _r = _t->save();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->quality_changed_by_slider((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->quality_changed_by_spinbox((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 4: _t->set_bitrate((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 5: _t->enable_min_bitrate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->set_minbitrate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->enable_max_bitrate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->set_maxbitrate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->trigger_changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (oggencWidget::*)()>(_a, &oggencWidget::triggerChanged, 0))
            return;
    }
}

const QMetaObject *oggencWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *oggencWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12oggencWidgetE_t>.strings))
        return static_cast<void*>(this);
    return oggencWidgetUI::qt_metacast(_clname);
}

int oggencWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = oggencWidgetUI::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void oggencWidget::triggerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
